@@ -1,6 +1,10 @@
+'''
+Date: 2022-07-20 15:22:19
+LastEditors: mushan wwd137669793@gmail.com
+LastEditTime: 2023-01-06 23:41:36
+FilePath: /mushan/mushan/__init__.py
+'''
 
-
-from mushan import shell
 from mushan import audio
 from mushan import nb
 from mushan import ml
