@@ -1,14 +1,31 @@
-'''
-Date: 2022-08-11 14:40:52
-LastEditors: mushan wwd137669793@gmail.com
-LastEditTime: 2022-12-30 21:47:56
-FilePath: /mushan/mushan/dl/func.py
-'''
 import torch
 import os
 from varname import argname
 
 
+def enable_debug_mode():
+    os.environ['MUSHAN_DEBUG']= "1"
+    print("Debug model: Enable")
+
+def check_debug_mode():
+    return os.getenv('path') == "1"
+
+def disable_debug_mode():
+    os.environ['MUSHAN_DEBUG']= "0"
+    print("Debug model: Disable")
+    
+    
+def debug_shape(*args):
+    for i in range(len(args)):
+        assert isinstance(args[i], torch.Tensor)
+        print(f"{argname(f'args[{i}]')}.shape: {str(list(args[i].shape))}, {str(args[i].dtype)[6:]}")
+
+
+def print_shape(*args):
+    for i in range(len(args)):
+        assert isinstance(args[i], torch.Tensor)
+        print(f"{argname(f'args[{i}]')}.shape: {str(list(args[i].shape))}, {str(args[i].dtype)[6:]}")
+
 def get_device():
     
     return torch.device('cuda' if torch.cuda.is_available() else 'cpu')
@@ -49,7 +66,3 @@ def set_cuda(gpus=None):
         print("Total Visible CUDA Device Count: {}".format(torch.cuda.device_count()))
     
     
-def printShape(*args):
-    for i in range(len(args)):
-        assert isinstance(args[i], torch.Tensor)
-        print(f"{argname(f'args[{i}]')}.shape: {str(list(args[i].shape))}, {str(args[i].dtype)[6:]}")
\ No newline at end of file
